import { ActionReducer, MetaReducer, Action, ActionReducerMap } from '@ngrx/store';
import * as fromRouter from '@ngrx/router-store';
import { InjectionToken } from '@angular/core';
/**
 * Every reducer module's default export is the reducer function itself. In
 * addition, each module should export a type or interface that describes
 * the state of the reducer plus any selector functions. The `* as`
 * notation packages up all of the exports into a single object.
 */
import * as fromUser from './user.reducer';
/**
 * As mentioned, we treat each reducer like a table in a database. This means
 * our top level state interface is just a map of keys to inner state types.
 */
export interface State {
    [fromUser.userFeatureKey]: fromUser.UserStateModel;
    router: fromRouter.RouterReducerState<any>;
}
/**
 * Our state is composed of a map of action reducer functions.
 * These reducer functions are called with each dispatched action
 * and the current or initial state and return a new immutable state.
 */
export declare const ROOT_REDUCERS: InjectionToken<ActionReducerMap<State, Action>>;
export declare function logger(reducer: ActionReducer<State>): ActionReducer<State>;
/**
 * By default, @ngrx/store uses combineReducers with the reducer map to compose
 * the root meta-reducer. To add more meta-reducers, provide an array of meta-reducers
 * that will be composed to form the root meta-reducer.
 */
export declare const metaReducers: MetaReducer<State>[];
/**
 * User Selectors
 */
export declare const selectUserState: import("@ngrx/store").MemoizedSelector<State, fromUser.UserStateModel, import("@ngrx/store").DefaultProjectorFn<fromUser.UserStateModel>>;
export declare const selectUsers: import("@ngrx/store").MemoizedSelector<State, import("share-state").User[], import("@ngrx/store").DefaultProjectorFn<import("share-state").User[]>>;
/**
 * Router Selectors
 */
export declare const selectRouter: import("@ngrx/store").MemoizedSelector<State, fromRouter.RouterReducerState<fromRouter.SerializedRouterStateSnapshot>, import("@ngrx/store").DefaultProjectorFn<fromRouter.RouterReducerState<fromRouter.SerializedRouterStateSnapshot>>>;
export declare const selectRouteData: import("@ngrx/store").MemoizedSelector<State, import("@angular/router").Data, import("@ngrx/store").DefaultProjectorFn<import("@angular/router").Data>>;
